==> google_shopping_merchant_lfp-0.1.1-py3-none-any.whl: google/shopping/merchant_lfp_v1beta/services/lfp_inventory_service/transports/rest.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import dataclasses
import json  # type: ignore
import re
from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
import warnings

from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
from google.api_core import exceptions as core_exceptions
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.grpc import SslCredentials  # type: ignore
from google.auth.transport.requests import AuthorizedSession  # type: ignore
from google.protobuf import json_format
import grpc  # type: ignore
from requests import __version__ as requests_version

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault, None]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object, None]  # type: ignore


from google.shopping.merchant_lfp_v1beta.types import lfpinventory

from .base import DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
from .base import LfpInventoryServiceTransport

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
    grpc_version=None,
    rest_version=requests_version,
)


class LfpInventoryServiceRestInterceptor:
    """Interceptor for LfpInventoryService.

    Interceptors are used to manipulate requests, request metadata, and responses
    in arbitrary ways.
    Example use cases include:
    * Logging
    * Verifying requests according to service or custom semantics
    * Stripping extraneous information from responses

    These use cases and more can be enabled by injecting an
    instance of a custom subclass when constructing the LfpInventoryServiceRestTransport.

    .. code-block:: python
        class MyCustomLfpInventoryServiceInterceptor(LfpInventoryServiceRestInterceptor):
            def pre_insert_lfp_inventory(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_insert_lfp_inventory(self, response):
                logging.log(f"Received response: {response}")
                return response

        transport = LfpInventoryServiceRestTransport(interceptor=MyCustomLfpInventoryServiceInterceptor())
        client = LfpInventoryServiceClient(transport=transport)


    """

    def pre_insert_lfp_inventory(
        self,
        request: lfpinventory.InsertLfpInventoryRequest,
        metadata: Sequence[Tuple[str, str]],
    ) -> Tuple[lfpinventory.InsertLfpInventoryRequest, Sequence[Tuple[str, str]]]:
        """Pre-rpc interceptor for insert_lfp_inventory

        Override in a subclass to manipulate the request or metadata
        before they are sent to the LfpInventoryService server.
        """
        return request, metadata

    def post_insert_lfp_inventory(
        self, response: lfpinventory.LfpInventory
    ) -> lfpinventory.LfpInventory:
        """Post-rpc interceptor for insert_lfp_inventory

        Override in a subclass to manipulate the response
        after it is returned by the LfpInventoryService server but before
        it is returned to user code.
        """
        return response


@dataclasses.dataclass
class LfpInventoryServiceRestStub:
    _session: AuthorizedSession
    _host: str
    _interceptor: LfpInventoryServiceRestInterceptor


class LfpInventoryServiceRestTransport(LfpInventoryServiceTransport):
    """REST backend transport for LfpInventoryService.

    Service for a `LFP
    partner <https://support.google.com/merchants/answer/7676652>`__ to
    submit local inventories for a merchant.

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends JSON representations of protocol buffers over HTTP/1.1

    """

    def __init__(
        self,
        *,
        host: str = "merchantapi.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        url_scheme: str = "https",
        interceptor: Optional[LfpInventoryServiceRestInterceptor] = None,
        api_audience: Optional[str] = None,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'merchantapi.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.

            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if ``channel`` is provided.
            scopes (Optional(Sequence[str])): A list of scopes. This argument is
                ignored if ``channel`` is provided.
            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
                certificate to configure mutual TLS HTTP channel. It is ignored
                if ``channel`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you are developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
            url_scheme: the protocol scheme for the API endpoint.  Normally
                "https", but for testing or local servers,
                "http" can be specified.
        """
        # Run the base constructor
        # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
        # credentials object
        maybe_url_match = re.match("^(?P<scheme>http(?:s)?://)?(?P<host>.*)$", host)
        if maybe_url_match is None:
            raise ValueError(
                f"Unexpected hostname structure: {host}"
            )  # pragma: NO COVER

        url_match_items = maybe_url_match.groupdict()

        host = f"{url_scheme}://{host}" if not url_match_items["scheme"] else host

        super().__init__(
            host=host,
            credentials=credentials,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
            api_audience=api_audience,
        )
        self._session = AuthorizedSession(
            self._credentials, default_host=self.DEFAULT_HOST
        )
        if client_cert_source_for_mtls:
            self._session.configure_mtls_channel(client_cert_source_for_mtls)
        self._interceptor = interceptor or LfpInventoryServiceRestInterceptor()
        self._prep_wrapped_messages(client_info)

    class _InsertLfpInventory(LfpInventoryServiceRestStub):
        def __hash__(self):
            return hash("InsertLfpInventory")

        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}

        @classmethod
        def _get_unset_required_fields(cls, message_dict):
            return {
                k: v
                for k, v in cls.__REQUIRED_FIELDS_DEFAULT_VALUES.items()
                if k not in message_dict
            }

        def __call__(
            self,
            request: lfpinventory.InsertLfpInventoryRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, str]] = (),
        ) -> lfpinventory.LfpInventory:
            r"""Call the insert lfp inventory method over HTTP.

            Args:
                request (~.lfpinventory.InsertLfpInventoryRequest):
                    The request object. Request message for the ``InsertLfpInventory`` method.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, str]]): Strings which should be
                    sent along with the request as metadata.

            Returns:
                ~.lfpinventory.LfpInventory:
                    Local Inventory for the merchant.
            """

            http_options: List[Dict[str, str]] = [
                {
                    "method": "post",
                    "uri": "/lfp/v1beta/{parent=accounts/*}/lfpInventories:insert",
                    "body": "lfp_inventory",
                },
            ]
            request, metadata = self._interceptor.pre_insert_lfp_inventory(
                request, metadata
            )
            pb_request = lfpinventory.InsertLfpInventoryRequest.pb(request)
            transcoded_request = path_template.transcode(http_options, pb_request)

            # Jsonify the request body

            body = json_format.MessageToJson(
                transcoded_request["body"], use_integers_for_enums=True
            )
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]

            # Jsonify the query params
            query_params = json.loads(
                json_format.MessageToJson(
                    transcoded_request["query_params"],
                    use_integers_for_enums=True,
                )
            )
            query_params.update(self._get_unset_required_fields(query_params))

            query_params["$alt"] = "json;enum-encoding=int"

            # Send the request
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(self._session, method)(
                "{host}{uri}".format(host=self._host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
                data=body,
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = lfpinventory.LfpInventory()
            pb_resp = lfpinventory.LfpInventory.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
            resp = self._interceptor.post_insert_lfp_inventory(resp)
            return resp

    @property
    def insert_lfp_inventory(
        self,
    ) -> Callable[[lfpinventory.InsertLfpInventoryRequest], lfpinventory.LfpInventory]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._InsertLfpInventory(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def kind(self) -> str:
        return "rest"

    def close(self):
        self._session.close()


__all__ = ("LfpInventoryServiceRestTransport",)

==> google_shopping_merchant_lfp-0.1.8-py3-none-any.whl: google/shopping/merchant_lfp_v1beta/services/lfp_inventory_service/transports/rest.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import dataclasses
import json  # type: ignore
import logging
from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
import warnings

from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, rest_helpers, rest_streaming
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.requests import AuthorizedSession  # type: ignore
from google.protobuf import json_format
from requests import __version__ as requests_version

from google.shopping.merchant_lfp_v1beta.types import lfpinventory

from .base import DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
from .rest_base import _BaseLfpInventoryServiceRestTransport

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault, None]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object, None]  # type: ignore

try:
    from google.api_core import client_logging  # type: ignore

    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
except ImportError:  # pragma: NO COVER
    CLIENT_LOGGING_SUPPORTED = False

_LOGGER = logging.getLogger(__name__)

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
    grpc_version=None,
    rest_version=f"requests@{requests_version}",
)


class LfpInventoryServiceRestInterceptor:
    """Interceptor for LfpInventoryService.

    Interceptors are used to manipulate requests, request metadata, and responses
    in arbitrary ways.
    Example use cases include:
    * Logging
    * Verifying requests according to service or custom semantics
    * Stripping extraneous information from responses

    These use cases and more can be enabled by injecting an
    instance of a custom subclass when constructing the LfpInventoryServiceRestTransport.

    .. code-block:: python
        class MyCustomLfpInventoryServiceInterceptor(LfpInventoryServiceRestInterceptor):
            def pre_insert_lfp_inventory(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_insert_lfp_inventory(self, response):
                logging.log(f"Received response: {response}")
                return response

        transport = LfpInventoryServiceRestTransport(interceptor=MyCustomLfpInventoryServiceInterceptor())
        client = LfpInventoryServiceClient(transport=transport)


    """

    def pre_insert_lfp_inventory(
        self,
        request: lfpinventory.InsertLfpInventoryRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[
        lfpinventory.InsertLfpInventoryRequest, Sequence[Tuple[str, Union[str, bytes]]]
    ]:
        """Pre-rpc interceptor for insert_lfp_inventory

        Override in a subclass to manipulate the request or metadata
        before they are sent to the LfpInventoryService server.
        """
        return request, metadata

    def post_insert_lfp_inventory(
        self, response: lfpinventory.LfpInventory
    ) -> lfpinventory.LfpInventory:
        """Post-rpc interceptor for insert_lfp_inventory

        DEPRECATED. Please use the `post_insert_lfp_inventory_with_metadata`
        interceptor instead.

        Override in a subclass to read or manipulate the response
        after it is returned by the LfpInventoryService server but before
        it is returned to user code. This `post_insert_lfp_inventory` interceptor runs
        before the `post_insert_lfp_inventory_with_metadata` interceptor.
        """
        return response

    def post_insert_lfp_inventory_with_metadata(
        self,
        response: lfpinventory.LfpInventory,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[lfpinventory.LfpInventory, Sequence[Tuple[str, Union[str, bytes]]]]:
        """Post-rpc interceptor for insert_lfp_inventory

        Override in a subclass to read or manipulate the response or metadata after it
        is returned by the LfpInventoryService server but before it is returned to user code.

        We recommend only using this `post_insert_lfp_inventory_with_metadata`
        interceptor in new development instead of the `post_insert_lfp_inventory` interceptor.
        When both interceptors are used, this `post_insert_lfp_inventory_with_metadata` interceptor runs after the
        `post_insert_lfp_inventory` interceptor. The (possibly modified) response returned by
        `post_insert_lfp_inventory` will be passed to
        `post_insert_lfp_inventory_with_metadata`.
        """
        return response, metadata


@dataclasses.dataclass
class LfpInventoryServiceRestStub:
    _session: AuthorizedSession
    _host: str
    _interceptor: LfpInventoryServiceRestInterceptor


class LfpInventoryServiceRestTransport(_BaseLfpInventoryServiceRestTransport):
    """REST backend synchronous transport for LfpInventoryService.

    Service for a `LFP
    partner <https://support.google.com/merchants/answer/7676652>`__ to
    submit local inventories for a merchant.

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends JSON representations of protocol buffers over HTTP/1.1
    """

    def __init__(
        self,
        *,
        host: str = "merchantapi.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        url_scheme: str = "https",
        interceptor: Optional[LfpInventoryServiceRestInterceptor] = None,
        api_audience: Optional[str] = None,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'merchantapi.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.

            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if ``channel`` is provided.
            scopes (Optional(Sequence[str])): A list of scopes. This argument is
                ignored if ``channel`` is provided.
            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
                certificate to configure mutual TLS HTTP channel. It is ignored
                if ``channel`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you are developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
            url_scheme: the protocol scheme for the API endpoint.  Normally
                "https", but for testing or local servers,
                "http" can be specified.
        """
        # Run the base constructor
        # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
        # credentials object
        super().__init__(
            host=host,
            credentials=credentials,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
            url_scheme=url_scheme,
            api_audience=api_audience,
        )
        self._session = AuthorizedSession(
            self._credentials, default_host=self.DEFAULT_HOST
        )
        if client_cert_source_for_mtls:
            self._session.configure_mtls_channel(client_cert_source_for_mtls)
        self._interceptor = interceptor or LfpInventoryServiceRestInterceptor()
        self._prep_wrapped_messages(client_info)

    class _InsertLfpInventory(
        _BaseLfpInventoryServiceRestTransport._BaseInsertLfpInventory,
        LfpInventoryServiceRestStub,
    ):
        def __hash__(self):
            return hash("LfpInventoryServiceRestTransport.InsertLfpInventory")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
                data=body,
            )
            return response

        def __call__(
            self,
            request: lfpinventory.InsertLfpInventoryRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> lfpinventory.LfpInventory:
            r"""Call the insert lfp inventory method over HTTP.

            Args:
                request (~.lfpinventory.InsertLfpInventoryRequest):
                    The request object. Request message for the ``InsertLfpInventory`` method.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.lfpinventory.LfpInventory:
                    Local Inventory for the merchant.
            """

            http_options = (
                _BaseLfpInventoryServiceRestTransport._BaseInsertLfpInventory._get_http_options()
            )

            request, metadata = self._interceptor.pre_insert_lfp_inventory(
                request, metadata
            )
            transcoded_request = _BaseLfpInventoryServiceRestTransport._BaseInsertLfpInventory._get_transcoded_request(
                http_options, request
            )

            body = _BaseLfpInventoryServiceRestTransport._BaseInsertLfpInventory._get_request_body_json(
                transcoded_request
            )

            # Jsonify the query params
            query_params = _BaseLfpInventoryServiceRestTransport._BaseInsertLfpInventory._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.shopping.merchant.lfp_v1beta.LfpInventoryServiceClient.InsertLfpInventory",
                    extra={
                        "serviceName": "google.shopping.merchant.lfp.v1beta.LfpInventoryService",
                        "rpcName": "InsertLfpInventory",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = (
                LfpInventoryServiceRestTransport._InsertLfpInventory._get_response(
                    self._host,
                    metadata,
                    query_params,
                    self._session,
                    timeout,
                    transcoded_request,
                    body,
                )
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = lfpinventory.LfpInventory()
            pb_resp = lfpinventory.LfpInventory.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_insert_lfp_inventory(resp)
            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
            resp, _ = self._interceptor.post_insert_lfp_inventory_with_metadata(
                resp, response_metadata
            )
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = lfpinventory.LfpInventory.to_json(response)
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.shopping.merchant.lfp_v1beta.LfpInventoryServiceClient.insert_lfp_inventory",
                    extra={
                        "serviceName": "google.shopping.merchant.lfp.v1beta.LfpInventoryService",
                        "rpcName": "InsertLfpInventory",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    @property
    def insert_lfp_inventory(
        self,
    ) -> Callable[[lfpinventory.InsertLfpInventoryRequest], lfpinventory.LfpInventory]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._InsertLfpInventory(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def kind(self) -> str:
        return "rest"

    def close(self):
        self._session.close()


__all__ = ("LfpInventoryServiceRestTransport",)
